#!/bin/sh
#
#	@(#) noadminwarn.shinc 12.7 97/10/31 
#
# Copyright (c) 1997 The Santa Cruz Operation, Inc.. All Rights Reserved.
# THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF THE SANTA CRUZ OPERATION INC.
# The copyright notice above does not evidence any actual or intended
# publication of such source code.
#


##########################################################################
#
# shell script to warn if there is no ns admin server present
#
# check for a file that indicates the presence of a valid admin server,
# and pops up a warning menu if it isn't there
#
# Arguments are:
#
#	[-q]		- run without producing menus
#	menu_path	- path to the directory containing the forms
#			  and messages
#
# Exit codes are:
#
#	0		- success - the admin server is there
#	1		- failure - no admin server found
#
##########################################################################

# definitions
TRUE=1; FALSE=0
SUCCESS=0; FAIL=1
ME="`basename $0 .sh`"
USAGE="Usage: $ME menu_path"
MESSAGES_DEFS="noadminwarn.msgs"
NSADMIN_CHECK_FILE="/etc/nsadmin"

# trap to ignore signals
trap '' 1 2 3 15

# arguments for directories and file definitions
QUIET=$FALSE
while getopts "q" opt; do
	case "$opt" in
	'q')	QUIET=$TRUE		;;
	'?')	echo "$USAGE" >&2
		exit $FAIL		;;
	esac
done
shift `expr $OPTIND - 1`
if [ $# -ne 1 ]; then
	echo "$USAGE" >&2
	exit $FAIL
fi

MENU_PATH="$1"
if [ "`echo \"$MENU_PATH\" | cut -c1`" != '/' ]; then
	# not absolute, so add pwd to make absolute
	MENU_PATH="`pwd`/$MENU_PATH"
fi

# set up our path
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/etc
export PATH

# read message definitions; alternatives if we can't do menus
if [ -f $MENU_PATH/$MESSAGES_DEFS ]; then
	. $MENU_PATH/$MESSAGES_DEFS
else
	echo "$ME: internal error - no $MESSAGES_DEFS file found" >&2
	exit $FAIL
fi

# symbols to help find menus and menu processing
MENU_COLORS="menu_colors"
ERROR_COLOR="error"
WARNING_COLOR="warn"
REGULAR_COLOR="regular"
MENU="menu"
MENU_TMPFILE="/tmp/noadminwarn.menu$$"
NOADMINWARN_MENU="menu.noadminwarn01"

# menu stuff
LOCALE="${LC_ALL:-${LC_MESSAGES:-${LANG:-C}}}"
# set up to use menu_colors; default to C-locale if locale's dir has
# no menu_colors.sh
if [ -f /etc/inst/locale/$LOCALE/menus/menu_colors.sh ]
then
	. /etc/inst/locale/$LOCALE/menus/menu_colors.sh
else
	if [ -f /etc/inst/locale/C/menus/menu_colors.sh ]; then
		. /etc/inst/locale/C/menus/menu_colors.sh
	else
		echo "$ME: internal error - no /etc/inst/locale/C/menus/menu_colors.sh file found" >&2
		exit $FAIL
	fi
fi


##########################################################################
#
# Menu forms library function
#	$1 - name of the form to run
#	$2 - file to send form (menu) -o output to
#	$3 - color set to use (regular, warn, or error)
#	$4 - string to eval as forms arguments
#
##########################################################################
run_form()
{
	# catch function parameters
	form_name="$1"
	output_file="$2"
	color="$3"
	form_args="$4"

	# set requested menu colors
	$MENU_COLORS $color

	# find the form that we have been asked to run; complain if
	# not there
	form_path="$MENU_PATH/$form_name"
	if [ ! -f "$form_path" ]; then
		echo "$ME: internal error - no form $form_name" >&2
		exit $FAIL
	fi

	# build a form header line
	form_header="$ME`[ -n "$PKGNAME" ] && echo \" ($PKGNAME)\"`"

	# run the form and send output to $2 parameter
	eval "FORM_HEADER=\"$form_header\" $form_args \
			$MENU $form_opts -f $form_path -o $output_file"
} # run_form()


##########################################################################
#
# main
#
##########################################################################

# if we are called from pkgadd then PKG will be set to the id of the
# package, and NAME will be set to the package name - trap these so
# they can be used in forms to remind the user what exactly they are
# installing
PKGNAME=""
if [ -n "$PKG" ]; then
	PKGNAME="$NAME"
fi

# check for the existence of a valid-looking admin server
if [ ! -x $NSADMIN_CHECK_FILE ]; then

	# no file found, so pop up the warning form or print the
	# message
	if [ $QUIET -ne $TRUE ]; then
		run_form "$NOADMINWARN_MENU" "$MENU_TMPFILE" "$WARNING_COLOR" ""
		rm -f $MENU_TMPFILE
	else
		echo "\n\n$MSG_NOADMINSERVER\n" >&2
	fi
	exit $FAIL
fi

# done
exit $SUCCESS
